==> payment-sdk-java-21.2.1-sources.jar: travel/wink/sdk/payment/api/StripeApi.java <==
package travel.wink.sdk.payment.api;

import travel.wink.sdk.payment.invoker.ApiClient;

import travel.wink.sdk.payment.model.BookingContractResponse;
import travel.wink.sdk.payment.model.CreatePaymentIntentRequest;
import travel.wink.sdk.payment.model.CreatePaymentIntentResponse;
import travel.wink.sdk.payment.model.CreateStripeSaleRequest;
import travel.wink.sdk.payment.model.CustomerPaymentMethodsResponse;

import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.core.ParameterizedTypeReference;
import org.springframework.web.reactive.function.client.WebClient.ResponseSpec;
import org.springframework.web.reactive.function.client.WebClientResponseException;
import org.springframework.core.io.FileSystemResource;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import reactor.core.publisher.Mono;
import reactor.core.publisher.Flux;

@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2022-08-16T13:28:00.702907+07:00[Asia/Bangkok]")
public class StripeApi {
    private ApiClient apiClient;

    public StripeApi() {
        this(new ApiClient());
    }

    @Autowired
    public StripeApi(ApiClient apiClient) {
        this.apiClient = apiClient;
    }

    public ApiClient getApiClient() {
        return apiClient;
    }

    public void setApiClient(ApiClient apiClient) {
        this.apiClient = apiClient;
    }

    /**
     * Create Stripe Payment Intent
     * Creates a Stripe PaymentIntent and creates a new customer for that intent.
     * <p><b>201</b> - Created
     * @param createPaymentIntentRequest The createPaymentIntentRequest parameter
     * @return CreatePaymentIntentResponse
     * @throws WebClientResponseException if an error occurs while attempting to invoke the API
     */
    private ResponseSpec createPaymentIntentRequestCreation(CreatePaymentIntentRequest createPaymentIntentRequest) throws WebClientResponseException {
        Object postBody = createPaymentIntentRequest;
        // verify the required parameter 'createPaymentIntentRequest' is set
        if (createPaymentIntentRequest == null) {
            throw new WebClientResponseException("Missing the required parameter 'createPaymentIntentRequest' when calling createPaymentIntent", HttpStatus.BAD_REQUEST.value(), HttpStatus.BAD_REQUEST.getReasonPhrase(), null, null, null);
        }
        // create path and map variables
        final Map<String, Object> pathParams = new HashMap<String, Object>();

        final MultiValueMap<String, String> queryParams = new LinkedMultiValueMap<String, String>();
        final HttpHeaders headerParams = new HttpHeaders();
        final MultiValueMap<String, String> cookieParams = new LinkedMultiValueMap<String, String>();
        final MultiValueMap<String, Object> formParams = new LinkedMultiValueMap<String, Object>();

        final String[] localVarAccepts = { 
            "application/vnd.platform-v1+json", "application/json"
        };
        final List<MediaType> localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);
        final String[] localVarContentTypes = { 
            "application/vnd.platform-v1+json", "application/json"
        };
        final MediaType localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

        String[] localVarAuthNames = new String[] { "oauth2_client_credentials" };

        ParameterizedTypeReference<CreatePaymentIntentResponse> localVarReturnType = new ParameterizedTypeReference<CreatePaymentIntentResponse>() {};
        return apiClient.invokeAPI("/api/payment/stripe/payment/intent", HttpMethod.POST, pathParams, queryParams, postBody, headerParams, cookieParams, formParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
    }

    /**
     * Create Stripe Payment Intent
     * Creates a Stripe PaymentIntent and creates a new customer for that intent.
     * <p><b>201</b> - Created
     * @param createPaymentIntentRequest The createPaymentIntentRequest parameter
     * @return CreatePaymentIntentResponse
     * @throws WebClientResponseException if an error occurs while attempting to invoke the API
     */
    public Mono<CreatePaymentIntentResponse> createPaymentIntent(CreatePaymentIntentRequest createPaymentIntentRequest) throws WebClientResponseException {
        ParameterizedTypeReference<CreatePaymentIntentResponse> localVarReturnType = new ParameterizedTypeReference<CreatePaymentIntentResponse>() {};
        return createPaymentIntentRequestCreation(createPaymentIntentRequest).bodyToMono(localVarReturnType);
    }

    public Mono<ResponseEntity<CreatePaymentIntentResponse>> createPaymentIntentWithHttpInfo(CreatePaymentIntentRequest createPaymentIntentRequest) throws WebClientResponseException {
        ParameterizedTypeReference<CreatePaymentIntentResponse> localVarReturnType = new ParameterizedTypeReference<CreatePaymentIntentResponse>() {};
        return createPaymentIntentRequestCreation(createPaymentIntentRequest).toEntity(localVarReturnType);
    }
    /**
     * Complete Stripe Capture
     * Upon a successful card capture, we store customer details for later use.
     * <p><b>201</b> - Created
     * @param createStripeSaleRequest The createStripeSaleRequest parameter
     * @return BookingContractResponse
     * @throws WebClientResponseException if an error occurs while attempting to invoke the API
     */
    private ResponseSpec savePayingCustomerRequestCreation(CreateStripeSaleRequest createStripeSaleRequest) throws WebClientResponseException {
        Object postBody = createStripeSaleRequest;
        // verify the required parameter 'createStripeSaleRequest' is set
        if (createStripeSaleRequest == null) {
            throw new WebClientResponseException("Missing the required parameter 'createStripeSaleRequest' when calling savePayingCustomer", HttpStatus.BAD_REQUEST.value(), HttpStatus.BAD_REQUEST.getReasonPhrase(), null, null, null);
        }
        // create path and map variables
        final Map<String, Object> pathParams = new HashMap<String, Object>();

        final MultiValueMap<String, String> queryParams = new LinkedMultiValueMap<String, String>();
        final HttpHeaders headerParams = new HttpHeaders();
        final MultiValueMap<String, String> cookieParams = new LinkedMultiValueMap<String, String>();
        final MultiValueMap<String, Object> formParams = new LinkedMultiValueMap<String, Object>();

        final String[] localVarAccepts = { 
            "application/vnd.platform-v1+json", "application/json"
        };
        final List<MediaType> localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);
        final String[] localVarContentTypes = { 
            "application/vnd.platform-v1+json", "application/json"
        };
        final MediaType localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

        String[] localVarAuthNames = new String[] { "oauth2_client_credentials" };

        ParameterizedTypeReference<BookingContractResponse> localVarReturnType = new ParameterizedTypeReference<BookingContractResponse>() {};
        return apiClient.invokeAPI("/api/payment/stripe/sale", HttpMethod.POST, pathParams, queryParams, postBody, headerParams, cookieParams, formParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
    }

    /**
     * Complete Stripe Capture
     * Upon a successful card capture, we store customer details for later use.
     * <p><b>201</b> - Created
     * @param createStripeSaleRequest The createStripeSaleRequest parameter
     * @return BookingContractResponse
     * @throws WebClientResponseException if an error occurs while attempting to invoke the API
     */
    public Mono<BookingContractResponse> savePayingCustomer(CreateStripeSaleRequest createStripeSaleRequest) throws WebClientResponseException {
        ParameterizedTypeReference<BookingContractResponse> localVarReturnType = new ParameterizedTypeReference<BookingContractResponse>() {};
        return savePayingCustomerRequestCreation(createStripeSaleRequest).bodyToMono(localVarReturnType);
    }

    public Mono<ResponseEntity<BookingContractResponse>> savePayingCustomerWithHttpInfo(CreateStripeSaleRequest createStripeSaleRequest) throws WebClientResponseException {
        ParameterizedTypeReference<BookingContractResponse> localVarReturnType = new ParameterizedTypeReference<BookingContractResponse>() {};
        return savePayingCustomerRequestCreation(createStripeSaleRequest).toEntity(localVarReturnType);
    }
    /**
     * List Payment Methods
     * List past payment methods by an existing customer record.
     * <p><b>200</b> - OK
     * @param acquirerId The acquirerId parameter
     * @param accept The accept parameter
     * @return CustomerPaymentMethodsResponse
     * @throws WebClientResponseException if an error occurs while attempting to invoke the API
     */
    private ResponseSpec showCustomerPaymentMethodsRequestCreation(String acquirerId, String accept) throws WebClientResponseException {
        Object postBody = null;
        // verify the required parameter 'acquirerId' is set
        if (acquirerId == null) {
            throw new WebClientResponseException("Missing the required parameter 'acquirerId' when calling showCustomerPaymentMethods", HttpStatus.BAD_REQUEST.value(), HttpStatus.BAD_REQUEST.getReasonPhrase(), null, null, null);
        }
        // create path and map variables
        final Map<String, Object> pathParams = new HashMap<String, Object>();

        final MultiValueMap<String, String> queryParams = new LinkedMultiValueMap<String, String>();
        final HttpHeaders headerParams = new HttpHeaders();
        final MultiValueMap<String, String> cookieParams = new LinkedMultiValueMap<String, String>();
        final MultiValueMap<String, Object> formParams = new LinkedMultiValueMap<String, Object>();

        queryParams.putAll(apiClient.parameterToMultiValueMap(null, "acquirerId", acquirerId));

        if (accept != null)
        headerParams.add("Accept", apiClient.parameterToString(accept));
        final String[] localVarAccepts = { 
            "application/vnd.platform-v1+json", "application/json"
        };
        final List<MediaType> localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);
        final String[] localVarContentTypes = { };
        final MediaType localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

        String[] localVarAuthNames = new String[] { "oauth2_client_credentials" };

        ParameterizedTypeReference<CustomerPaymentMethodsResponse> localVarReturnType = new ParameterizedTypeReference<CustomerPaymentMethodsResponse>() {};
        return apiClient.invokeAPI("/api/payment/stripe/payment/method/list", HttpMethod.GET, pathParams, queryParams, postBody, headerParams, cookieParams, formParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
    }

    /**
     * List Payment Methods
     * List past payment methods by an existing customer record.
     * <p><b>200</b> - OK
     * @param acquirerId The acquirerId parameter
     * @param accept The accept parameter
     * @return CustomerPaymentMethodsResponse
     * @throws WebClientResponseException if an error occurs while attempting to invoke the API
     */
    public Mono<CustomerPaymentMethodsResponse> showCustomerPaymentMethods(String acquirerId, String accept) throws WebClientResponseException {
        ParameterizedTypeReference<CustomerPaymentMethodsResponse> localVarReturnType = new ParameterizedTypeReference<CustomerPaymentMethodsResponse>() {};
        return showCustomerPaymentMethodsRequestCreation(acquirerId, accept).bodyToMono(localVarReturnType);
    }

    public Mono<ResponseEntity<CustomerPaymentMethodsResponse>> showCustomerPaymentMethodsWithHttpInfo(String acquirerId, String accept) throws WebClientResponseException {
        ParameterizedTypeReference<CustomerPaymentMethodsResponse> localVarReturnType = new ParameterizedTypeReference<CustomerPaymentMethodsResponse>() {};
        return showCustomerPaymentMethodsRequestCreation(acquirerId, accept).toEntity(localVarReturnType);
    }
}

==> payment-sdk-java-21.3.0-sources.jar: travel/wink/sdk/payment/api/StripeApi.java <==
package travel.wink.sdk.payment.api;

import travel.wink.sdk.payment.invoker.ApiClient;

import travel.wink.sdk.payment.model.BookingContractResponse;
import travel.wink.sdk.payment.model.CreatePaymentIntentRequest;
import travel.wink.sdk.payment.model.CreatePaymentIntentResponse;
import travel.wink.sdk.payment.model.CreateStripeSaleRequest;
import travel.wink.sdk.payment.model.CustomerPaymentMethodsResponse;

import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.core.ParameterizedTypeReference;
import org.springframework.web.reactive.function.client.WebClient.ResponseSpec;
import org.springframework.web.reactive.function.client.WebClientResponseException;
import org.springframework.core.io.FileSystemResource;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import reactor.core.publisher.Mono;
import reactor.core.publisher.Flux;

@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2022-09-06T15:31:16.117259+07:00[Asia/Bangkok]")
public class StripeApi {
    private ApiClient apiClient;

    public StripeApi() {
        this(new ApiClient());
    }

    @Autowired
    public StripeApi(ApiClient apiClient) {
        this.apiClient = apiClient;
    }

    public ApiClient getApiClient() {
        return apiClient;
    }

    public void setApiClient(ApiClient apiClient) {
        this.apiClient = apiClient;
    }

    /**
     * Complete Stripe Capture
     * Upon a successful card capture, we store customer details for later use.
     * <p><b>201</b> - Created
     * @param createStripeSaleRequest The createStripeSaleRequest parameter
     * @return BookingContractResponse
     * @throws WebClientResponseException if an error occurs while attempting to invoke the API
     */
    private ResponseSpec captureSaleRequestCreation(CreateStripeSaleRequest createStripeSaleRequest) throws WebClientResponseException {
        Object postBody = createStripeSaleRequest;
        // verify the required parameter 'createStripeSaleRequest' is set
        if (createStripeSaleRequest == null) {
            throw new WebClientResponseException("Missing the required parameter 'createStripeSaleRequest' when calling captureSale", HttpStatus.BAD_REQUEST.value(), HttpStatus.BAD_REQUEST.getReasonPhrase(), null, null, null);
        }
        // create path and map variables
        final Map<String, Object> pathParams = new HashMap<String, Object>();

        final MultiValueMap<String, String> queryParams = new LinkedMultiValueMap<String, String>();
        final HttpHeaders headerParams = new HttpHeaders();
        final MultiValueMap<String, String> cookieParams = new LinkedMultiValueMap<String, String>();
        final MultiValueMap<String, Object> formParams = new LinkedMultiValueMap<String, Object>();

        final String[] localVarAccepts = { 
            "application/vnd.platform-v1+json", "application/json"
        };
        final List<MediaType> localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);
        final String[] localVarContentTypes = { 
            "application/vnd.platform-v1+json", "application/json"
        };
        final MediaType localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

        String[] localVarAuthNames = new String[] { "oauth2_client_credentials" };

        ParameterizedTypeReference<BookingContractResponse> localVarReturnType = new ParameterizedTypeReference<BookingContractResponse>() {};
        return apiClient.invokeAPI("/api/payment/stripe/sale", HttpMethod.POST, pathParams, queryParams, postBody, headerParams, cookieParams, formParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
    }

    /**
     * Complete Stripe Capture
     * Upon a successful card capture, we store customer details for later use.
     * <p><b>201</b> - Created
     * @param createStripeSaleRequest The createStripeSaleRequest parameter
     * @return BookingContractResponse
     * @throws WebClientResponseException if an error occurs while attempting to invoke the API
     */
    public Mono<BookingContractResponse> captureSale(CreateStripeSaleRequest createStripeSaleRequest) throws WebClientResponseException {
        ParameterizedTypeReference<BookingContractResponse> localVarReturnType = new ParameterizedTypeReference<BookingContractResponse>() {};
        return captureSaleRequestCreation(createStripeSaleRequest).bodyToMono(localVarReturnType);
    }

    public Mono<ResponseEntity<BookingContractResponse>> captureSaleWithHttpInfo(CreateStripeSaleRequest createStripeSaleRequest) throws WebClientResponseException {
        ParameterizedTypeReference<BookingContractResponse> localVarReturnType = new ParameterizedTypeReference<BookingContractResponse>() {};
        return captureSaleRequestCreation(createStripeSaleRequest).toEntity(localVarReturnType);
    }
    /**
     * Create Stripe Payment Intent
     * Creates a Stripe PaymentIntent and creates a new customer for that intent.
     * <p><b>201</b> - Created
     * @param createPaymentIntentRequest The createPaymentIntentRequest parameter
     * @return CreatePaymentIntentResponse
     * @throws WebClientResponseException if an error occurs while attempting to invoke the API
     */
    private ResponseSpec createPaymentIntentRequestCreation(CreatePaymentIntentRequest createPaymentIntentRequest) throws WebClientResponseException {
        Object postBody = createPaymentIntentRequest;
        // verify the required parameter 'createPaymentIntentRequest' is set
        if (createPaymentIntentRequest == null) {
            throw new WebClientResponseException("Missing the required parameter 'createPaymentIntentRequest' when calling createPaymentIntent", HttpStatus.BAD_REQUEST.value(), HttpStatus.BAD_REQUEST.getReasonPhrase(), null, null, null);
        }
        // create path and map variables
        final Map<String, Object> pathParams = new HashMap<String, Object>();

        final MultiValueMap<String, String> queryParams = new LinkedMultiValueMap<String, String>();
        final HttpHeaders headerParams = new HttpHeaders();
        final MultiValueMap<String, String> cookieParams = new LinkedMultiValueMap<String, String>();
        final MultiValueMap<String, Object> formParams = new LinkedMultiValueMap<String, Object>();

        final String[] localVarAccepts = { 
            "application/vnd.platform-v1+json", "application/json"
        };
        final List<MediaType> localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);
        final String[] localVarContentTypes = { 
            "application/vnd.platform-v1+json", "application/json"
        };
        final MediaType localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

        String[] localVarAuthNames = new String[] { "oauth2_client_credentials" };

        ParameterizedTypeReference<CreatePaymentIntentResponse> localVarReturnType = new ParameterizedTypeReference<CreatePaymentIntentResponse>() {};
        return apiClient.invokeAPI("/api/payment/stripe/payment/intent", HttpMethod.POST, pathParams, queryParams, postBody, headerParams, cookieParams, formParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
    }

    /**
     * Create Stripe Payment Intent
     * Creates a Stripe PaymentIntent and creates a new customer for that intent.
     * <p><b>201</b> - Created
     * @param createPaymentIntentRequest The createPaymentIntentRequest parameter
     * @return CreatePaymentIntentResponse
     * @throws WebClientResponseException if an error occurs while attempting to invoke the API
     */
    public Mono<CreatePaymentIntentResponse> createPaymentIntent(CreatePaymentIntentRequest createPaymentIntentRequest) throws WebClientResponseException {
        ParameterizedTypeReference<CreatePaymentIntentResponse> localVarReturnType = new ParameterizedTypeReference<CreatePaymentIntentResponse>() {};
        return createPaymentIntentRequestCreation(createPaymentIntentRequest).bodyToMono(localVarReturnType);
    }

    public Mono<ResponseEntity<CreatePaymentIntentResponse>> createPaymentIntentWithHttpInfo(CreatePaymentIntentRequest createPaymentIntentRequest) throws WebClientResponseException {
        ParameterizedTypeReference<CreatePaymentIntentResponse> localVarReturnType = new ParameterizedTypeReference<CreatePaymentIntentResponse>() {};
        return createPaymentIntentRequestCreation(createPaymentIntentRequest).toEntity(localVarReturnType);
    }
    /**
     * List Payment Methods
     * List past payment methods by an existing customer record.
     * <p><b>200</b> - OK
     * @param acquirerId The acquirerId parameter
     * @param accept The accept parameter
     * @return CustomerPaymentMethodsResponse
     * @throws WebClientResponseException if an error occurs while attempting to invoke the API
     */
    private ResponseSpec showCustomerPaymentMethodsRequestCreation(String acquirerId, String accept) throws WebClientResponseException {
        Object postBody = null;
        // verify the required parameter 'acquirerId' is set
        if (acquirerId == null) {
            throw new WebClientResponseException("Missing the required parameter 'acquirerId' when calling showCustomerPaymentMethods", HttpStatus.BAD_REQUEST.value(), HttpStatus.BAD_REQUEST.getReasonPhrase(), null, null, null);
        }
        // create path and map variables
        final Map<String, Object> pathParams = new HashMap<String, Object>();

        final MultiValueMap<String, String> queryParams = new LinkedMultiValueMap<String, String>();
        final HttpHeaders headerParams = new HttpHeaders();
        final MultiValueMap<String, String> cookieParams = new LinkedMultiValueMap<String, String>();
        final MultiValueMap<String, Object> formParams = new LinkedMultiValueMap<String, Object>();

        queryParams.putAll(apiClient.parameterToMultiValueMap(null, "acquirerId", acquirerId));

        if (accept != null)
        headerParams.add("Accept", apiClient.parameterToString(accept));
        final String[] localVarAccepts = { 
            "application/vnd.platform-v1+json", "application/json"
        };
        final List<MediaType> localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);
        final String[] localVarContentTypes = { };
        final MediaType localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

        String[] localVarAuthNames = new String[] { "oauth2_client_credentials" };

        ParameterizedTypeReference<CustomerPaymentMethodsResponse> localVarReturnType = new ParameterizedTypeReference<CustomerPaymentMethodsResponse>() {};
        return apiClient.invokeAPI("/api/payment/stripe/payment/method/list", HttpMethod.GET, pathParams, queryParams, postBody, headerParams, cookieParams, formParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
    }

    /**
     * List Payment Methods
     * List past payment methods by an existing customer record.
     * <p><b>200</b> - OK
     * @param acquirerId The acquirerId parameter
     * @param accept The accept parameter
     * @return CustomerPaymentMethodsResponse
     * @throws WebClientResponseException if an error occurs while attempting to invoke the API
     */
    public Mono<CustomerPaymentMethodsResponse> showCustomerPaymentMethods(String acquirerId, String accept) throws WebClientResponseException {
        ParameterizedTypeReference<CustomerPaymentMethodsResponse> localVarReturnType = new ParameterizedTypeReference<CustomerPaymentMethodsResponse>() {};
        return showCustomerPaymentMethodsRequestCreation(acquirerId, accept).bodyToMono(localVarReturnType);
    }

    public Mono<ResponseEntity<CustomerPaymentMethodsResponse>> showCustomerPaymentMethodsWithHttpInfo(String acquirerId, String accept) throws WebClientResponseException {
        ParameterizedTypeReference<CustomerPaymentMethodsResponse> localVarReturnType = new ParameterizedTypeReference<CustomerPaymentMethodsResponse>() {};
        return showCustomerPaymentMethodsRequestCreation(acquirerId, accept).toEntity(localVarReturnType);
    }
}
